// call GNUPLOT to run autonomously

// command contains the command file name

// CALLING METHOD
#define CREATEPROCESS                    // for win95 or winNT
//#define WINEXEC                          // for windows 3.1
//#define SPAWNLP                          // alternative for win95 or winNT
//#define FORK                             // for unix


# ifdef CREATEPROCESS

// This version is for windows NT or windows 95

#include <windows.h>

#define WANT_STREAM
#include "include.h"
#include "str.h"
#include "callplot.h"

void CallPlot(const String& command)
{
   String command_line = ("WGNUPLOT.EXE "+command);
   char cl[100]; int sz = command_line.copy(cl, 100); cl[sz]=0;
   STARTUPINFO startupinfo =
   {
      68,0,0,0,0,0,0,0,0,0,0,STARTF_USESHOWWINDOW,SW_SHOWMINIMIZED,0,0,0,0,0
   };

   PROCESS_INFORMATION PI;
   int w = CreateProcess(
      "WGNUPLOT.EXE",
      cl,
      0,
      0,
      0,
      CREATE_SEPARATE_WOW_VDM,
      0,
      0,
      &startupinfo,
      &PI);

   if (w==0) Throw(Runtime_error("Call to gnuplot fails\n"));
}

#endif

#ifdef WINEXEC

// This version is for windows 3.1

#include <windows.h>

#define WANT_STREAM
#include "include.h"
#include "str.h"
#include "callplot.h"

void CallPlot(const String& command)
{
   int w =
      WinExec((String("WGNUPLOT ")+command).c_str(), SW_SHOWMINIMIZED);
   if (w==16)
      Throw(Runtime_error(
         "Call to gnuplot fails; one copy already running?\n"));
   if (w<32) Throw(Runtime_error("Call to gnuplot fails\n"));
}

#endif

#ifdef SPAWNLP

// This is an alternative version for WIN32

#include <process.h>

#define WANT_STREAM
#include "include.h"
#include "str.h"
#include "callplot.h"

void CallPlot(const String& command)
{
   int w =
      spawnlp(P_DETACH, "WGNUPLOT", "WGNUPLOT", command.c_str(), (char*)0);
   if (w < 0) Throw(Runtime_error("Call to gnuplot fails\n"));
}

#endif

#ifdef FORK

// This version is for Unix

// Version for UNIX

#define WANT_STREAM
#include "include.h"
#include "str.h"
#include "callplot.h"
#include "unistd.h"

void CallPlot(const String& command)
{
   int w;
   if ((w = fork()) == 0)
   {
       execlp("gnuplot","gnuplot", command.c_str(), (char*)0);
       cout << "Call to gnuplot fails" << endl;
       exit(0);
       // but this won't stop main process
   }
}

#endif


